@@ -449,7 +449,7 @@ my $__extract_nodejs_info = sub ($c_key, $l_key, $file, $grant, $current_dir) {
             else {
                 @c_data = ($data->{$c_key}->@*);
             }
-        } else {
+        } elsif (defined $data->{$c_key}) {
             @c_data = ($data->{$c_key});
         }
 
@@ -550,6 +550,11 @@ sub __apply_fill_blank ($self, $file, $grant) {
     if ( not $l and $fill_blank->{license} ) {
         $grant->license( $fill_blank->{license});
     }
+
+    if ( not $grant->comment and $fill_blank->{comment} ) {
+        $grant->comment( $fill_blank->{comment});
+    }
+
     return ;
 }
 
